@@ -58,6 +58,7 @@ namespace gnote {
     TrieController(NoteManager &);
     ~TrieController();
 
+    void add_note(const Note::Ptr & note);
     void update();
     TrieTree<Note::WeakPtr> *title_trie() const
       {
@@ -281,13 +282,13 @@ namespace gnote {
     try {
       Note::Ptr start_note = create (_("Start Here"),
                                 start_note_content);
-      start_note->queue_save (Note::CONTENT_CHANGED);
+      start_note->queue_save (CONTENT_CHANGED);
       Preferences::obj().get_schema_settings(Preferences::SCHEMA_GNOTE)->set_string(
           Preferences::START_NOTE_URI, start_note->uri());
 
       Note::Ptr links_note = create (_("Using Links in Gnote"),
                                 links_note_content);
-      links_note->queue_save (Note::CONTENT_CHANGED);
+      links_note->queue_save (CONTENT_CHANGED);
 
       m_signal_start_note_created(start_note);
     } 
@@ -368,7 +369,7 @@ namespace gnote {
         }
         
         note->set_is_open_on_startup(false);
-        note->queue_save (Note::NO_CHANGE);
+        note->queue_save (NO_CHANGE);
       }
     }
   }
@@ -665,7 +666,7 @@ namespace gnote {
       Tag::Ptr template_tag = TagManager::obj().get_or_create_system_tag (TagManager::TEMPLATE_NOTE_SYSTEM_TAG);
       template_note->add_tag(template_tag);
 
-      template_note->queue_save(Note::CONTENT_CHANGED);
+      template_note->queue_save(CONTENT_CHANGED);
     }
       
     return template_note;
@@ -747,9 +748,9 @@ namespace gnote {
     delete m_title_trie;
   }
 
-  void TrieController::on_note_added (const Note::Ptr & )
+  void TrieController::on_note_added (const Note::Ptr & note)
   {
-    update ();
+    add_note (note);
   }
 
   void TrieController::on_note_deleted (const Note::Ptr & )
@@ -762,6 +763,12 @@ namespace gnote {
     update ();
   }
 
+  void TrieController::add_note(const Note::Ptr & note)
+  {
+    m_title_trie->add_keyword (note->get_title(), note);
+    m_title_trie->compute_failure_graph();
+  }
+
   void TrieController::update ()
   {
     if(m_title_trie) {
@@ -774,6 +781,7 @@ namespace gnote {
       const Note::Ptr & note(*iter);
       m_title_trie->add_keyword (note->get_title(), note);
     }
+    m_title_trie->compute_failure_graph();
   }
 
 }
